<?php



require_once 'Classes/General/DateRange.php';
require_once 'Classes/Astro/SkyCoord.php';



/**
 * This class represents the parameters used in a cone query search.
 **/

class ConeQueryParameters
{
  // PUBLIC

  public function __construct( ConeQueryParameters $rhs = null )
  {
    $this->date_range = new DateRange();
    $this->project_id = '';
    $this->coordinates = new SkyCoord();
    $this->search_radius = 30;
    $this->obs_mode = '';
    $this->data_type = '';
    $this->bands = Array();
    $this->cals_timeframe = 0;
    $this->order_column = 'file_id';
    $this->order_direction = 'desc';

    if( !ConeQueryParameters::$static_setup )
      $this->SetupStaticData();
    
    if( $rhs != null )
      $this->Copy( $rhs );
  }
  
  public function Copy( $rhs )
  {
    $this->date_range = new DateRange( $rhs->date_range );
    $this->project_id = $rhs->project_id;
    $this->coordinates = new SkyCoord( $rhs->coordinates );
    $this->search_radius = $rhs->search_radius;
    $this->obs_mode = $rhs->obs_mode;
    $this->data_type = $rhs->data_type;
    
    $this->bandnames = Array();
    foreach( $this->bandnames as $next_band )
      $this->bandnames[] = new Band( $next_band );
    
    $this->cals_timeframe = $rhs->cals_timeframe;
  }

  public function SetDateRange( $s_date_range ) { $this->date_range = $s_date_range; }
  public function GetDateRange() { return $this->date_range; }

  public function SetProjectID( $s_project_id ) { $this->project_id = $s_project_id; }
  public function GetProjectID() { return $this->project_id; }

  public function SetCoordinates( $s_coordinates ) { $this->coordinates = $s_coordinates; }
  public function GetCoordinates() { return $this->coordinates; }

  public function SetSearchRadius( $s_search_radius ) { $this->search_radius = $s_search_radius; }
  public function GetSearchRadius() { return $this->search_radius; }

  public function SetObsMode( $s_obs_mode ) { $this->obs_mode = $s_obs_mode; }
  public function GetObsMode() { return $this->obs_mode; }

  public function SetDataType( $s_data_type ) { $this->data_type = $s_data_type; }
  public function GetDataType() { return $this->data_type; }

  public function SetCalsTimeframe( $s_cals_timeframe ) { $this->cals_timeframe = $s_cals_timeframe; }
  public function GetCalsTimeframe() { return $this->cals_timeframe; }
  
  public function SetOrderDirection( $s_order_direction ) { $this->order_direction = $s_order_direction; }
  public function GetOrderDirection() { return $this->order_direction; }
  
  public function SetOrderColumn( $s_order_column ) { $this->order_column = $s_order_column; }
  public function GetOrderColumn() { return $this->order_column; }

  public function SetBands( $s_bands ) 
  {
    if( is_array( $s_bands ) )
    {
      $this->bands = $s_bands;
    }
  }
  public function GetBands() { return $this->bands; }
  public function AddBand( $s_band ) { $this->bands[] = $s_band; }
  
  public function SetAuthorizedProjects( $s_projects ) { $this->authorized_projects = $s_projects; }
  public function GetAuthorizedProjects() { return $this->authorized_projects; }
  
  public function AreValid()
  {
    return true;
  }

  // PRIVATE

  private $date_range;
  private $project_id;
  private $coordinates;
  private $search_radius;
  private $obs_mode;
  private $data_type;
  private $bands;
  private $order_column;
  private $order_direction;
  private $cals_timeframe;
  private $authorized_projects;

  // STATIC

  private function SetupStaticData()
  {
    // TODO query the database for a list of valid data types
    ConeQueryParameters::$static_setup = true;
  }

  static public $static_setup = false;
  static public $valid_obs_modes = Array( 'Any', 'Only Timing', 'Only Search Data' );

};




?>